@@ -55,32 +55,25 @@ extern bool also_the_last;
 
 extern int didfind;
 
-extern int controlleft;
-extern int controlright;
-extern int controlup;
-extern int controldown;
-extern int controlhome;
-extern int controlend;
+extern int controlleft, controlright;
+extern int controlup, controldown;
+extern int controlhome, controlend;
 #ifndef NANO_TINY
-extern int shiftcontrolleft;
-extern int shiftcontrolright;
-extern int shiftcontrolup;
-extern int shiftcontroldown;
-extern int shiftcontrolhome;
-extern int shiftcontrolend;
-extern int altleft;
-extern int altright;
-extern int altup;
-extern int altdown;
-extern int shiftaltleft;
-extern int shiftaltright;
-extern int shiftaltup;
-extern int shiftaltdown;
+extern int controldelete, controlshiftdelete;
+extern int shiftleft, shiftright;
+extern int shiftup, shiftdown;
+extern int shiftcontrolleft, shiftcontrolright;
+extern int shiftcontrolup, shiftcontroldown;
+extern int shiftcontrolhome, shiftcontrolend;
+extern int altleft, altright;
+extern int altup, altdown;
+extern int altdelete;
+extern int shiftaltleft, shiftaltright;
+extern int shiftaltup, shiftaltdown;
 #endif
 
 #ifdef ENABLED_WRAPORJUSTIFY
-extern ssize_t fill;
-extern ssize_t wrap_at;
+extern ssize_t wrap_at, fill;
 #endif
 
 extern char *last_search;
@@ -124,7 +117,6 @@ extern char *quoteerr;
 extern char *word_chars;
 
 extern char *answer;
-extern size_t statusbar_x;
 
 extern ssize_t tabsize;
 
@@ -179,7 +171,13 @@ extern int interface_color_pair[NUMBER_OF_ELEMENTS];
 
 extern char *homedir;
 extern char *statedir;
+#ifdef ENABLE_NANORC
 extern char *rcfile_with_errors;
+#endif
+
+extern bool spotlighted;
+extern size_t light_from_col;
+extern size_t light_to_col;
 
 typedef void (*functionptrtype)(void);
 
@@ -190,7 +188,7 @@ void read_the_list(const char *path, DIR *dir);
 functionptrtype parse_browser_input(int *kbinput);
 void browser_refresh(void);
 void browser_select_dirname(const char *needle);
-void do_filesearch(void);
+void do_filesearch(bool forwards);
 void do_fileresearch(bool forwards);
 void to_first_file(void);
 void to_last_file(void);
@@ -222,7 +220,6 @@ char *mbstrcasestr(const char *haystack, const char *needle);
 char *revstrstr(const char *haystack, const char *needle, const char *index);
 char *mbrevstrcasestr(const char *haystack, const char *needle, const char *index);
 size_t mbstrlen(const char *s);
-size_t mbstrnlen(const char *s, size_t maxlen);
 #if !defined(NANO_TINY) || defined(ENABLE_JUSTIFY)
 char *mbstrchr(const char *s, const char *c);
 #endif
@@ -237,9 +234,6 @@ bool has_blank_mbchars(const char *s);
 #ifdef ENABLE_UTF8
 bool is_valid_unicode(wchar_t wc);
 #endif
-#ifdef ENABLE_NANORC
-bool is_valid_mbstring(const char *s);
-#endif
 
 /* Most functions in color.c. */
 #ifdef ENABLE_COLOR
@@ -253,15 +247,15 @@ void precalc_multicolorinfo(void);
 
 /* Most functions in cut.c. */
 void cutbuffer_reset(void);
-bool keeping_cutbuffer(void);
 #ifndef NANO_TINY
 void cut_marked(bool *right_side_up);
 #endif
-void do_cut_text(bool copy_text, bool cut_till_eof);
+void do_cut_text(bool copy_text, bool marked, bool cut_till_eof, bool append);
 void do_cut_text_void(void);
 #ifndef NANO_TINY
 void do_copy_text(void);
 void do_cut_till_eof(void);
+void zap_text(void);
 #endif
 void do_uncut_text(void);
 
@@ -272,12 +266,12 @@ bool open_buffer(const char *filename, bool new_buffer);
 #ifdef ENABLE_SPELLER
 void replace_buffer(const char *filename);
 #ifndef NANO_TINY
-void replace_marked_buffer(const char *filename, filestruct *top, size_t top_x,
-		filestruct *bot, size_t bot_x);
+void replace_marked_buffer(const char *filename);
 #endif
 #endif
 void prepare_for_display(void);
 #ifdef ENABLE_MULTIBUFFER
+void mention_name_and_linecount(void);
 void switch_to_prev_buffer(void);
 void switch_to_next_buffer(void);
 bool close_buffer(void);
@@ -325,16 +319,12 @@ int keycode_from_string(const char *keystring);
 void assign_keyinfo(sc *s, const char *keystring, const int keycode);
 void print_sclist(void);
 void shortcut_init(void);
-#ifdef ENABLE_COLOR
-void set_lint_or_format_shortcuts(void);
-void set_spell_shortcuts(void);
-#endif
 const subnfunc *sctofunc(const sc *s);
 const char *flagtostr(int flag);
+#ifdef ENABLE_NANORC
 sc *strtosc(const char *input);
-int strtomenu(const char *input);
-#ifdef DEBUG
-void thanks_for_all_the_fish(void);
+int name_to_menu(const char *name);
+char *menu_to_name(int menu);
 #endif
 
 /* All functions in help.c. */
@@ -373,22 +363,22 @@ void to_last_line(void);
 void do_page_up(void);
 void do_page_down(void);
 #ifdef ENABLE_JUSTIFY
-void do_para_begin(bool update_screen);
-void do_para_end(bool update_screen);
+void do_para_begin(void);
+void do_para_end(void);
 void do_para_begin_void(void);
 void do_para_end_void(void);
 #endif
 void do_prev_block(void);
 void do_next_block(void);
-void do_prev_word(bool allow_punct, bool update_screen);
-bool do_next_word(bool after_ends, bool allow_punct, bool update_screen);
+void do_prev_word(bool allow_punct);
+bool do_next_word(bool after_ends, bool allow_punct);
 void do_prev_word_void(void);
 void do_next_word_void(void);
 void do_home(void);
 void do_end(void);
 void do_up(void);
 void do_down(void);
-#ifdef ENABLE_HELP
+#if !defined(NANO_TINY) || defined(ENABLE_HELP)
 void do_scroll_up(void);
 void do_scroll_down(void);
 #endif
@@ -410,7 +400,6 @@ void extract_buffer(filestruct **file_top, filestruct **file_bot,
 		filestruct *top, size_t top_x, filestruct *bot, size_t bot_x);
 void ingraft_buffer(filestruct *somebuffer);
 void copy_from_buffer(filestruct *somebuffer);
-openfilestruct *make_new_opennode(void);
 #ifdef ENABLE_MULTIBUFFER
 void unlink_opennode(openfilestruct *fileptr);
 void delete_opennode(openfilestruct *fileptr);
@@ -435,7 +424,6 @@ RETSIGTYPE do_continue(int signal);
 #ifndef NANO_TINY
 RETSIGTYPE handle_sigwinch(int signal);
 void regenerate_screen(void);
-void allow_sigwinch(bool allow);
 void do_toggle(int flag);
 void enable_signals(void);
 #endif
@@ -465,10 +453,9 @@ void do_statusbar_prev_word(void);
 void do_statusbar_next_word(void);
 #endif
 void do_statusbar_verbatim_input(void);
-size_t statusbar_xplustabs(void);
 size_t get_statusbar_page_start(size_t start_col, size_t column);
-void reinit_statusbar_x(void);
-void update_the_statusbar(void);
+void put_cursor_at_end_of_answer(void);
+void add_or_remove_pipe_symbol_from_answer(void);
 int do_prompt(bool allow_tabs, bool allow_files,
 		int menu, const char *curranswer, filestruct **history_list,
 		void (*refresh_func)(void), const char *msg, ...);
@@ -490,11 +477,8 @@ int findnextstr(const char *needle, bool whole_word_only, int modus,
 void do_search(void);
 void do_search_forward(void);
 void do_search_backward(void);
-void do_research(void);
-#ifndef NANO_TINY
 void do_findprevious(void);
 void do_findnext(void);
-#endif
 void not_found_msg(const char *str);
 void go_looking(void);
 ssize_t do_replace_loop(const char *needle, bool whole_word_only,
@@ -562,7 +546,6 @@ void do_spell(void);
 #endif
 #ifdef ENABLE_COLOR
 void do_linter(void);
-void do_formatter(void);
 #endif
 #ifndef NANO_TINY
 void do_wordlinechar_count(void);
@@ -616,9 +599,6 @@ size_t get_totsize(const filestruct *begin, const filestruct *end);
 #ifndef NANO_TINY
 filestruct *fsfromline(ssize_t lineno);
 #endif
-#ifdef DEBUG
-void dump_filestruct(const filestruct *inptr);
-#endif
 
 /* Most functions in winio.c. */
 void record_macro(void);
@@ -681,12 +661,11 @@ void edit_refresh(void);
 void adjust_viewport(update_type location);
 void total_redraw(void);
 void total_refresh(void);
-void display_main_list(void);
 void do_cursorpos(bool force);
 void do_cursorpos_void(void);
-void spotlight(bool active, size_t from_col, size_t to_col);
+void spotlight(size_t from_col, size_t to_col);
 #ifndef NANO_TINY
-void spotlight_softwrapped(bool active, size_t from_col, size_t to_col);
+void spotlight_softwrapped(size_t from_col, size_t to_col);
 #endif
 void do_suspend_void(void);
 void disable_waiting(void);
@@ -714,6 +693,7 @@ void prepend_void(void);
 void backup_file_void(void);
 void flip_execute(void);
 void flip_pipe(void);
+void flip_convert(void);
 #endif
 #ifdef ENABLE_MULTIBUFFER
 void flip_newbuffer(void);
